xeus_zmq: ZeroMQ-based middleware for xeus
==========================================

Description
-----------

xeus-zmq provides various implementations of the xserver API from xeus, based on the ZeroMQ library.


License
-------

BSD-3-Clause license


Upstream Contact
----------------

https://github.com/jupyter-xeus/xeus-zmq
